/*
*     ___                       ____               __
*    / _ \___ _    _____ ____  /  _/__  ___  __ __/ /_
*   / ___/ _ \ |/|/ / -_) __/ _/ // _ \/ _ \/ // / __/
*  /_/   \___/__,__/\__/_/   /___/_//_/ .__/\_,_/\__/
*                                    /_/
*
*   Original Code by John Garrison
*   Written August 27, 1999
*   To be released under the LGPL
*
*   Keyboard interface routines
*
*   See LICENSE.TXT for more LGPL info
*/
#ifndef _PI_joystick_H
#define _PI_joystick_H

#include "powerinput.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifdef linux
  #include <linux/joystick.h>
  #define JOY_DEV1 "/dev/js0"
  #define JOY_DEV2 "/dev/js1"
  #if JS_VERSION >= 0x010000
    #define _pijmethod2_
  #else
  #define _pijmethod1_
  #endif
#endif

#ifdef __FREE_BSD_
  #include <machine/joystick.h>
  #define JOY_DEV1 "/dev/joy0"
  #define JOY_DEV2 "/dev/joy1"
  #define _pijmethod1_
#endif

#ifdef __WIN32__
  #define _pijmethod3_
#endif

typedef struct _JoyData{
   int axis[6];
   int button[8];
}PI_JoyData;

typedef int PI_JoyID;

int *axis=NULL, num_of_axis=0, num_of_buttons=0;
char name_of_joystick[80];
int joy_fd1, joy_fd2;

PI_JoyID PI_OpenJoystick(int Joy);
PI_JoyData PI_ReadJoystick(int Joy);

int PI_IsJoyButtonDown(int Joy, int Button);
int PI_WasJoyButtonPressed(PI_JoyData JoyData, int Button);

int PI_JoyAxisDirection(PI_JoyID Joy, int Axis);
int PI_JoyX(PI_JoyID Joy);
int PI_JoyY(PI_JoyID Joy);

#ifdef __cplusplus
};
#endif

#endif
